'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _CardActions = require('../layout/CardActions');

var _CardActions2 = _interopRequireDefault(_CardActions);

var _button = require('../button');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Action Toolbar for the Delete view
 * 
 * Internal component. If you want to add or remove actions for a Delete view,
 * write your own DeleteActions Component. Then, in the <Delete> component,
 * use it in the `actions` prop to pas a custom element.
 * 
 * @example
 *     import Button from 'material-ui/Button';
 *     import { CardActions, ListButton, ShowButton, EditButton, Delete } from 'react-admin';
 *     
 *     const PostDeleteActions = ({ basePath, data }) => (
 *         <CardActions>
 *             <ListButton basePath={basePath} />
 *             <EditButton basePath={basePath} record={data} />
 *             <ShowButton basePath={basePath} record={data} />
 *             // Add your custom actions here //
 *             <Button color="primary" onClick={customAction}>Custom Action</Button>
 *         </CardActions>
 *     );
 *     
 *     export const PostDelete = (props) => (
 *         <Delete actions={<PostDeleteActions />} {...props}>
 *             ...
 *         </Delete>
 *     );
 */
var DeleteActions = function DeleteActions(_ref) {
    var basePath = _ref.basePath,
        className = _ref.className,
        data = _ref.data,
        hasEdit = _ref.hasEdit,
        hasList = _ref.hasList,
        hasShow = _ref.hasShow,
        rest = (0, _objectWithoutProperties3.default)(_ref, ['basePath', 'className', 'data', 'hasEdit', 'hasList', 'hasShow']);
    return _react2.default.createElement(
        _CardActions2.default,
        (0, _extends3.default)({ className: className }, rest),
        hasList && _react2.default.createElement(_button.ListButton, { basePath: basePath }),
        hasEdit && _react2.default.createElement(_button.EditButton, { basePath: basePath, record: data }),
        hasShow && _react2.default.createElement(_button.ShowButton, { basePath: basePath, record: data })
    );
};

DeleteActions.propTypes = {
    basePath: _propTypes2.default.string,
    className: _propTypes2.default.string,
    data: _propTypes2.default.object,
    hasEdit: _propTypes2.default.bool,
    hasShow: _propTypes2.default.bool,
    hasList: _propTypes2.default.bool
};

exports.default = DeleteActions;
module.exports = exports['default'];