'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactRedux = require('react-redux');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _styles = require('material-ui/styles');

var _Hidden = require('material-ui/Hidden');

var _Hidden2 = _interopRequireDefault(_Hidden);

var _compose = require('recompose/compose');

var _compose2 = _interopRequireDefault(_compose);

var _AdminRoutes = require('../../AdminRoutes');

var _AdminRoutes2 = _interopRequireDefault(_AdminRoutes);

var _AppBar = require('./AppBar');

var _AppBar2 = _interopRequireDefault(_AppBar);

var _Sidebar = require('./Sidebar');

var _Sidebar2 = _interopRequireDefault(_Sidebar);

var _LoadingIndicator = require('./LoadingIndicator');

var _LoadingIndicator2 = _interopRequireDefault(_LoadingIndicator);

var _Menu = require('./Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _Notification = require('./Notification');

var _Notification2 = _interopRequireDefault(_Notification);

var _defaultTheme = require('../defaultTheme');

var _defaultTheme2 = _interopRequireDefault(_defaultTheme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = function styles(theme) {
    var _content;

    return {
        root: {
            width: '100%',
            zIndex: 1,
            overflow: 'hidden'
        },
        appFrame: {
            position: 'relative',
            display: 'flex',
            width: '100%',
            height: '100%'
        },
        content: (_content = {
            width: '100%',
            marginLeft: 0,
            flexGrow: 1,
            backgroundColor: theme.palette.background.default,
            padding: theme.spacing.unit * 3,
            transition: theme.transitions.create('margin', {
                easing: theme.transitions.easing.sharp,
                duration: theme.transitions.duration.leavingScreen
            }),
            height: 'calc(100% - 56px)'
        }, (0, _defineProperty3.default)(_content, theme.breakpoints.up('sm'), {
            content: {
                height: 'calc(100% - 64px)',
                marginTop: 64
            }
        }), (0, _defineProperty3.default)(_content, theme.breakpoints.up('xs'), {
            marginTop: '4em'
        }), (0, _defineProperty3.default)(_content, theme.breakpoints.down('sm'), {
            marginTop: '3em',
            padding: 0
        }), _content),
        contentShift: (0, _defineProperty3.default)({}, theme.breakpoints.up('sm'), {
            marginLeft: _Sidebar.DRAWER_WIDTH,
            transition: theme.transitions.create('margin', {
                easing: theme.transitions.easing.easeOut,
                duration: theme.transitions.duration.enteringScreen
            })
        })
    };
};

var Layout = function Layout(_ref) {
    var catchAll = _ref.catchAll,
        children = _ref.children,
        classes = _ref.classes,
        className = _ref.className,
        customRoutes = _ref.customRoutes,
        dashboard = _ref.dashboard,
        logout = _ref.logout,
        menu = _ref.menu,
        open = _ref.open,
        theme = _ref.theme,
        title = _ref.title,
        rest = (0, _objectWithoutProperties3.default)(_ref, ['catchAll', 'children', 'classes', 'className', 'customRoutes', 'dashboard', 'logout', 'menu', 'open', 'theme', 'title']);
    return _react2.default.createElement(
        _styles.MuiThemeProvider,
        { theme: (0, _styles.createMuiTheme)(theme) },
        _react2.default.createElement(
            'div',
            (0, _extends3.default)({ className: (0, _classnames2.default)(classes.root, className) }, rest),
            _react2.default.createElement(
                'div',
                { className: classes.appFrame },
                _react2.default.createElement(
                    _Hidden2.default,
                    { xsDown: true },
                    _react2.default.createElement(_AppBar2.default, { title: title, open: open })
                ),
                _react2.default.createElement(
                    _Sidebar2.default,
                    null,
                    (0, _react.createElement)(menu || _Menu2.default, {
                        logout: logout,
                        hasDashboard: !!dashboard
                    })
                ),
                _react2.default.createElement(
                    'main',
                    {
                        className: (0, _classnames2.default)(classes.content, open && classes.contentShift)
                    },
                    _react2.default.createElement(
                        _AdminRoutes2.default,
                        {
                            customRoutes: customRoutes,
                            dashboard: dashboard,
                            catchAll: catchAll,
                            title: title
                        },
                        children
                    )
                ),
                _react2.default.createElement(_Notification2.default, null),
                _react2.default.createElement(_LoadingIndicator2.default, null)
            )
        )
    );
};

var componentPropType = _propTypes2.default.oneOfType([_propTypes2.default.func, _propTypes2.default.string]);

Layout.propTypes = {
    children: _propTypes2.default.oneOfType([_propTypes2.default.func, _propTypes2.default.node]),
    classes: _propTypes2.default.object,
    className: _propTypes2.default.string,
    catchAll: componentPropType,
    customRoutes: _propTypes2.default.array,
    dashboard: componentPropType,
    logout: _propTypes2.default.oneOfType([_propTypes2.default.node, _propTypes2.default.func, _propTypes2.default.string]),
    menu: _propTypes2.default.oneOfType([_propTypes2.default.func, _propTypes2.default.string]),
    open: _propTypes2.default.bool,
    title: _propTypes2.default.node.isRequired,
    theme: _propTypes2.default.object.isRequired
};

Layout.defaultProps = {
    theme: _defaultTheme2.default
};

var mapStateToProps = function mapStateToProps(state) {
    return {
        open: state.admin.ui.sidebarOpen
    };
};
var enhance = (0, _compose2.default)((0, _reactRedux.connect)(mapStateToProps, {} // Avoid connect passing dispatch in props
), (0, _styles.withStyles)(styles));

exports.default = enhance(Layout);
module.exports = exports['default'];